@@ -7,7 +7,6 @@
 #' @rdname enum
 #' @examples
 #' \donttest{
-#' if (gd_is_initialized())
 #'   gd_enum_names()
 #' }
 gd_enum_names <- function() {
@@ -21,14 +20,19 @@ gd_enum_names <- function() {
 #' @examplesIf gd_is_initialized()
 #' @examples
 #' \donttest{
-#' if (gd_is_initialized())
 #'   gd_enum_elements()
 #' }
 gd_enum_elements <- function(enum = gd_enum_names()) {
   enum <- match.arg(enum, gd_enum_names(), several.ok = TRUE)
   res <- lapply(enum, function(x) {
     y <- gd$enums[[x]]
-    sapply(names(y), function(z) y[[z]]$value)
+    do.call('c', lapply(names(y), function(z) {
+      zz <- y[[z]]
+      if ("value" %in% names(zz)) {
+        zz$value
+      } else
+        NULL
+    }))
   })
   names(res) <- enum
   res
@@ -40,7 +44,6 @@ gd_enum_elements <- function(enum = gd_enum_names()) {
 #' @examplesIf gd_is_initialized()
 #' @examples
 #' \donttest{
-#' if (gd_is_initialized())
 #'   gd_resampling_methods()
 #' }
 gd_resampling_methods <- function() {
@@ -53,7 +56,6 @@ gd_resampling_methods <- function() {
 #' @examplesIf gd_is_initialized()
 #' @examples
 #' \donttest{
-#' if (gd_is_initialized())
 #'   gd_cloud_mask_methods()
 #' }
 gd_cloud_mask_methods <- function() {
@@ -66,7 +68,6 @@ gd_cloud_mask_methods <- function() {
 #' @examplesIf gd_is_initialized()
 #' @examples
 #' \donttest{
-#' if (gd_is_initialized())
 #'   gd_composite_methods()
 #' }
 gd_composite_methods <- function() {
@@ -80,9 +81,20 @@ gd_composite_methods <- function() {
 #' @examplesIf gd_is_initialized()
 #' @examples
 #' \donttest{
-#' if (gd_is_initialized())
 #'   gd_export_types()
 #' }
 gd_export_types <- function() {
   gd_enum_elements("ExportType")[[1]]
 }
+
+#' @return `gd_spectral_distance_metrics()`: character vector of spectral distance metrics (Enum `"SpectralDistanceMetric"`)
+#' @export
+#' @rdname enum
+#' @examplesIf gd_is_initialized()
+#' @examples
+#' \donttest{
+#'   gd_spectral_distance_metrics()
+#' }
+gd_spectral_distance_metrics <- function() {
+  gd_enum_elements("SpectralDistanceMetric")[[1]]
+}
